@@ -5,27 +5,21 @@ var dir_5ed74997c7e1c0d009d001d9d868ffa8 =
     [ "app.h", "app_8h.html", "app_8h" ],
     [ "deprecated.h", "deprecated_8h.html", null ],
     [ "doc.h", "doc_8h.html", "doc_8h" ],
-    [ "expr.h", "expr_8h.html", "expr_8h" ],
     [ "flecs_c.h", "flecs__c_8h.html", "flecs__c_8h" ],
     [ "flecs_cpp.h", "flecs__cpp_8h.html", null ],
     [ "http.h", "http_8h.html", "http_8h" ],
-    [ "journal.h", "journal_8h.html", null ],
     [ "json.h", "json_8h.html", "json_8h" ],
     [ "log.h", "log_8h.html", "log_8h" ],
     [ "meta.h", "meta_8h.html", "meta_8h" ],
     [ "meta_c.h", "meta__c_8h.html", "meta__c_8h" ],
     [ "metrics.h", "metrics_8h.html", "metrics_8h" ],
     [ "module.h", "module_8h.html", "module_8h" ],
-    [ "monitor.h", "monitor_8h.html", null ],
-    [ "os_api_impl.h", "os__api__impl_8h.html", null ],
-    [ "parser.h", "parser_8h.html", "parser_8h" ],
     [ "pipeline.h", "pipeline_8h.html", "pipeline_8h" ],
-    [ "plecs.h", "plecs_8h.html", "plecs_8h" ],
     [ "rest.h", "rest_8h.html", "rest_8h" ],
-    [ "rules.h", "rules_8h.html", "rules_8h" ],
-    [ "snapshot.h", "snapshot_8h.html", "snapshot_8h" ],
+    [ "script.h", "script_8h.html", "script_8h" ],
+    [ "script_math.h", "script__math_8h.html", null ],
     [ "stats.h", "stats_8h.html", "stats_8h" ],
     [ "system.h", "system_8h.html", "system_8h" ],
     [ "timer.h", "timer_8h.html", "timer_8h" ],
-    [ "units.h", "units_8h.html", null ]
+    [ "units.h", "units_8h.html", "units_8h" ]
 ];
\ No newline at end of file
