@@ -1,8 +1,5 @@
 var NAVTREEINDEX2 =
 {
-"group__c__addons__meta.html#ga65239f23769c834492a6021b382e5eba":[17,0,1,6,37],
-"group__c__addons__meta.html#ga655d6de4f969a41cbf775c6eecc6627d":[17,0,1,6,86],
-"group__c__addons__meta.html#ga6b1b83d88c9743379b88bd071609415e":[17,0,1,6,164],
 "group__c__addons__meta.html#ga6c8fb2d661e52dc55fed53948b992395":[17,0,1,6,105],
 "group__c__addons__meta.html#ga6dad8f8983a00b66474ce2ac068a8e2c":[17,0,1,6,155],
 "group__c__addons__meta.html#ga6dba5d1b917773290bace8041307cf3b":[17,0,1,6,120],
@@ -138,37 +135,56 @@ var NAVTREEINDEX2 =
 "group__c__addons__rest.html#ga78853d6049d045f6fe53288d394d32e8":[17,0,1,11,2],
 "group__c__addons__rest.html#ga93d6ee0f2eaa7ea62a04b85aa3a8c3fe":[17,0,1,11,4],
 "group__c__addons__script.html":[17,0,1,12],
-"group__c__addons__script.html#ga193cfa4859ca1dd26d2bac626d942e77":[17,0,1,12,16],
-"group__c__addons__script.html#ga1a13eb59cd49c32ee29a8b0adf3647cd":[17,0,1,12,7],
-"group__c__addons__script.html#ga2725ceb095305f1d9a26dbbd2f527680":[17,0,1,12,13],
-"group__c__addons__script.html#ga2db09932d9854713197a27261a2c156b":[17,0,1,12,30],
-"group__c__addons__script.html#ga31cba6f47d36b6c0fb799d4a4de5725a":[17,0,1,12,20],
-"group__c__addons__script.html#ga39d531da0e53709b7727a73fee2615d2":[17,0,1,12,11],
-"group__c__addons__script.html#ga3eb60f5fb3b9fb4bfffe7f9d57ede241":[17,0,1,12,12],
-"group__c__addons__script.html#ga50c4c5398a7287e456bdb97e57897e78":[17,0,1,12,14],
-"group__c__addons__script.html#ga5dfb5843b7487dbe98d1741a01afaa3c":[17,0,1,12,27],
-"group__c__addons__script.html#ga6eb42c3849e71ec532fd3e9c167abef4":[17,0,1,12,22],
-"group__c__addons__script.html#ga6eeef9ac6aa2f59f23c29bb54a263b90":[17,0,1,12,17],
-"group__c__addons__script.html#ga74bc8da5aae2dd76977de279e210ed94":[17,0,1,12,34],
-"group__c__addons__script.html#ga7826bc70d53586b5e14178fd264e5a28":[17,0,1,12,24],
-"group__c__addons__script.html#ga83bcaf8f75444ed89573e26f0715ec47":[17,0,1,12,18],
-"group__c__addons__script.html#ga85fb59b976057544e37b074a92ff5e1f":[17,0,1,12,28],
-"group__c__addons__script.html#ga8a7c387b656ef75b4fb875dbccee0933":[17,0,1,12,29],
-"group__c__addons__script.html#ga98a4f6c9ca40e3fe3ca3659eae83b60c":[17,0,1,12,31],
-"group__c__addons__script.html#ga9936fc113cd1eabe1e9fbada5043ea52":[17,0,1,12,21],
-"group__c__addons__script.html#ga9f723b42b86a0b842e9cf3df61031454":[17,0,1,12,8],
-"group__c__addons__script.html#gaa73d749d828e0bc764495f2652557d09":[17,0,1,12,15],
-"group__c__addons__script.html#gabd11ff241936e0809735f858820b241c":[17,0,1,12,6],
-"group__c__addons__script.html#gac0eb2a7d0530520ad5b23d4d1f50f0e6":[17,0,1,12,32],
-"group__c__addons__script.html#gad1df31aea9727c0f1311a2f7b327f13f":[17,0,1,12,35],
-"group__c__addons__script.html#gad5fc35c787e01f09e453494b531b580f":[17,0,1,12,10],
-"group__c__addons__script.html#gadd826e8e8b727ba43f8fb30b119cf6c4":[17,0,1,12,36],
-"group__c__addons__script.html#gade3fb3dd296857efe7a50b1997ef4aed":[17,0,1,12,26],
-"group__c__addons__script.html#gadf0746f95d33f91cdf450df8f877da64":[17,0,1,12,23],
-"group__c__addons__script.html#gaec75c699f24155ba4572ea33a07d6783":[17,0,1,12,9],
-"group__c__addons__script.html#gaf1f13c6829b865e22aac7fe7c3266dcc":[17,0,1,12,25],
-"group__c__addons__script.html#gaf20aa5bd2cf5b3a0c2e84bc5912a1085":[17,0,1,12,33],
-"group__c__addons__script.html#gaffd1f1f4a1f50a6187c7eff6c63f191a":[17,0,1,12,19],
+"group__c__addons__script.html#ga0fb2dba6d500f9f49601ea80b0cdfc79":[17,0,1,12,48],
+"group__c__addons__script.html#ga14132ad041c3be4085274275c2e44494":[17,0,1,12,60],
+"group__c__addons__script.html#ga1c5667be3bdd647fe5918caab23ec5b9":[17,0,1,12,62],
+"group__c__addons__script.html#ga2725ceb095305f1d9a26dbbd2f527680":[17,0,1,12,36],
+"group__c__addons__script.html#ga29a13cfac15e9d1203627e32d2cadfa9":[17,0,1,12,31],
+"group__c__addons__script.html#ga2db09932d9854713197a27261a2c156b":[17,0,1,12,54],
+"group__c__addons__script.html#ga2ed4f41e5ead16094b3a21daaa527d51":[17,0,1,12,15],
+"group__c__addons__script.html#ga3419040532bc19960c485c9047ffc1e9":[17,0,1,12,49],
+"group__c__addons__script.html#ga39d531da0e53709b7727a73fee2615d2":[17,0,1,12,25],
+"group__c__addons__script.html#ga3eb60f5fb3b9fb4bfffe7f9d57ede241":[17,0,1,12,35],
+"group__c__addons__script.html#ga4ba84f33bb79e49c5ed1bae6b09eb8c5":[17,0,1,12,33],
+"group__c__addons__script.html#ga4da28a1d04c4110bdfa237d40a6500e8":[17,0,1,12,45],
+"group__c__addons__script.html#ga5042cfbf9d9efc3abf87a60e74c55067":[17,0,1,12,26],
+"group__c__addons__script.html#ga50c4c5398a7287e456bdb97e57897e78":[17,0,1,12,37],
+"group__c__addons__script.html#ga5dfb5843b7487dbe98d1741a01afaa3c":[17,0,1,12,51],
+"group__c__addons__script.html#ga5f46fd666be35d76213a680b3d66816d":[17,0,1,12,40],
+"group__c__addons__script.html#ga60992b2b865dfd5396f11f28791e22d3":[17,0,1,12,16],
+"group__c__addons__script.html#ga6eb42c3849e71ec532fd3e9c167abef4":[17,0,1,12,44],
+"group__c__addons__script.html#ga741e37cf11e7d3aae8ba4f11cd9ba80b":[17,0,1,12,14],
+"group__c__addons__script.html#ga74bc8da5aae2dd76977de279e210ed94":[17,0,1,12,59],
+"group__c__addons__script.html#ga7826bc70d53586b5e14178fd264e5a28":[17,0,1,12,46],
+"group__c__addons__script.html#ga7a40442e85b4129e1415bb528a406723":[17,0,1,12,56],
+"group__c__addons__script.html#ga83bcaf8f75444ed89573e26f0715ec47":[17,0,1,12,41],
+"group__c__addons__script.html#ga85fb59b976057544e37b074a92ff5e1f":[17,0,1,12,52],
+"group__c__addons__script.html#ga8a7c387b656ef75b4fb875dbccee0933":[17,0,1,12,53],
+"group__c__addons__script.html#ga98a4f6c9ca40e3fe3ca3659eae83b60c":[17,0,1,12,55],
+"group__c__addons__script.html#ga9936fc113cd1eabe1e9fbada5043ea52":[17,0,1,12,43],
+"group__c__addons__script.html#ga9bdf387f68988be0ecd1208a050ebaf2":[17,0,1,12,39],
+"group__c__addons__script.html#ga9c1c3d1a3390ec375ca90aa2c11ef537":[17,0,1,12,34],
+"group__c__addons__script.html#ga9f723b42b86a0b842e9cf3df61031454":[17,0,1,12,22],
+"group__c__addons__script.html#gaa73d749d828e0bc764495f2652557d09":[17,0,1,12,38],
+"group__c__addons__script.html#gabb8874a5bba792070834ef25aab6f252":[17,0,1,12,42],
+"group__c__addons__script.html#gabd11ff241936e0809735f858820b241c":[17,0,1,12,19],
+"group__c__addons__script.html#gac0eb2a7d0530520ad5b23d4d1f50f0e6":[17,0,1,12,57],
+"group__c__addons__script.html#gac12e76ce0d556f79575bfa928f03c8c0":[17,0,1,12,30],
+"group__c__addons__script.html#gacd1db8af4037edf0988ef4c59b15de9b":[17,0,1,12,18],
+"group__c__addons__script.html#gad1df31aea9727c0f1311a2f7b327f13f":[17,0,1,12,61],
+"group__c__addons__script.html#gad30117e684bb8c4a5a0863ccc5621e9c":[17,0,1,12,20],
+"group__c__addons__script.html#gad5fc35c787e01f09e453494b531b580f":[17,0,1,12,24],
+"group__c__addons__script.html#gadcd26bfa929a7782c79095502de698af":[17,0,1,12,29],
+"group__c__addons__script.html#gadd826e8e8b727ba43f8fb30b119cf6c4":[17,0,1,12,63],
+"group__c__addons__script.html#gade3fb3dd296857efe7a50b1997ef4aed":[17,0,1,12,50],
+"group__c__addons__script.html#gae0dca6f94d8389111d8630354f38b913":[17,0,1,12,27],
+"group__c__addons__script.html#gae1e40e6dde27c2d35e80c3eabdb0adf6":[17,0,1,12,17],
+"group__c__addons__script.html#gae6c78d631e85db90cf35366bb8230d35":[17,0,1,12,21],
+"group__c__addons__script.html#gaec75c699f24155ba4572ea33a07d6783":[17,0,1,12,23],
+"group__c__addons__script.html#gaf1f13c6829b865e22aac7fe7c3266dcc":[17,0,1,12,47],
+"group__c__addons__script.html#gaf20aa5bd2cf5b3a0c2e84bc5912a1085":[17,0,1,12,58],
+"group__c__addons__script.html#gafe171aa539b5f0d2d90bf0e9bfa4165d":[17,0,1,12,28],
+"group__c__addons__script.html#gaff489cd13bbb23d877c6f8c79d2816cb":[17,0,1,12,32],
 "group__c__addons__stats.html":[17,0,1,13],
 "group__c__addons__stats.html#ga07c23bebfcbe59ac88ed0280749751b7":[17,0,1,13,46],
 "group__c__addons__stats.html#ga0c3002d17dd7893e5dca4f4657878e57":[17,0,1,13,15],
@@ -233,21 +249,5 @@ var NAVTREEINDEX2 =
 "group__c__addons__timer.html#ga714238af3396f265fd1d4b831d0c68c5":[17,0,1,15,10],
 "group__c__addons__timer.html#ga9830c3eed511595f34134cdec0e20b44":[17,0,1,15,9],
 "group__c__addons__timer.html#gaa3e8e5d3571ae39786291321c3601884":[17,0,1,15,14],
-"group__c__addons__timer.html#gaba6c4d4285b5515142ed5b5271febd86":[17,0,1,15,3],
-"group__c__addons__timer.html#gadb25a5cf160007351c1d28cda1e130bf":[17,0,1,15,12],
-"group__c__addons__timer.html#gadb9aec2c89c51a4da664e86868b8a023":[17,0,1,15,6],
-"group__c__addons__timer.html#gae510da7e9258c38c5770fb8bc84266fd":[17,0,1,15,11],
-"group__c__addons__timer.html#gaf964315a1be9c1e296c4fe41f516409b":[17,0,1,15,13],
-"group__c__addons__timer.html#gaf9ff76ebe120df160b1750a949b673a6":[17,0,1,15,2],
-"group__c__addons__units.html":[17,0,1,16],
-"group__c__addons__units.html#ga1a262c645dc495fbd6754a69f6c8bd60":[17,0,1,16,17],
-"group__c__addons__units.html#ga9bde018551030eb8bbd203f7008ffac1":[17,0,1,16,21],
-"group__c__addons__units.html#gaacb26f68f8780b0146b101d9fb6ec413":[17,0,1,16,20],
-"group__c__addons__units.html#gae2b1f09c1cb4a2befcd9b7ec8361e6ca":[17,0,1,16,18],
-"group__c__addons__units.html#gaf8013af729a5abe7b7d1ee8fbec7e7fd":[17,0,1,16,19],
-"group__c__addons__units__amount.html":[17,0,1,16,5],
-"group__c__addons__units__amount.html#ga476d35f741fb2883f8797f0a49629861":[17,0,1,16,5,1],
-"group__c__addons__units__amount.html#gab468eeacfed3f0b9d1f19a4479c1370f":[17,0,1,16,5,0],
-"group__c__addons__units__angle.html":[17,0,1,16,14],
-"group__c__addons__units__angle.html#ga308db2497c25c997adc500c3dadf8487":[17,0,1,16,14,2]
+"group__c__addons__timer.html#gaba6c4d4285b5515142ed5b5271febd86":[17,0,1,15,3]
 };
